@@ -5,12 +5,12 @@ module Thin
   
   module VERSION #:nodoc:
     MAJOR    = 1
-    MINOR    = 3
-    TINY     = 1
+    MINOR    = 6
+    TINY     = 3
     
     STRING   = [MAJOR, MINOR, TINY].join('.')
     
-    CODENAME = "Triple Espresso".freeze
+    CODENAME = "Protein Powder".freeze
     
     RACK     = [1, 0].freeze # Rack protocol version
   end
